==> extra-tool-installers-0.1-sources.jar: com/synopsys/arc/jenkinsci/plugins/extratoolinstallers/installers/Messages.java <==
// CHECKSTYLE:OFF

package com.synopsys.arc.jenkinsci.plugins.extratoolinstallers.installers;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Must provide a tool home directory.
     * 
     */
    public static String SharedDirectoryInstaller_no_toolHome() {
        return holder.format("SharedDirectoryInstaller.no_toolHome");
    }

    /**
     * Must provide a tool home directory.
     * 
     */
    public static Localizable _SharedDirectoryInstaller_no_toolHome() {
        return new Localizable(holder, "SharedDirectoryInstaller.no_toolHome");
    }

    /**
     * Use tool from specified directory
     * 
     */
    public static String SharedDirectoryInstaller_DescriptorImpl_displayName() {
        return holder.format("SharedDirectoryInstaller.DescriptorImpl.displayName");
    }

    /**
     * Use tool from specified directory
     * 
     */
    public static Localizable _SharedDirectoryInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "SharedDirectoryInstaller.DescriptorImpl.displayName");
    }

    /**
     * Must provide a tool home directory.
     * 
     */
    public static String BatchCommandInstaller_no_toolHome() {
        return holder.format("BatchCommandInstaller.no_toolHome");
    }

    /**
     * Must provide a tool home directory.
     * 
     */
    public static Localizable _BatchCommandInstaller_no_toolHome() {
        return new Localizable(holder, "BatchCommandInstaller.no_toolHome");
    }

    /**
     * Run Batch Command
     * 
     */
    public static String BatchCommandInstaller_DescriptorImpl_displayName() {
        return holder.format("BatchCommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Run Batch Command
     * 
     */
    public static Localizable _BatchCommandInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "BatchCommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Must provide a command to run.
     * 
     */
    public static String BatchCommandInstaller_no_command() {
        return holder.format("BatchCommandInstaller.no_command");
    }

    /**
     * Must provide a command to run.
     * 
     */
    public static Localizable _BatchCommandInstaller_no_command() {
        return new Localizable(holder, "BatchCommandInstaller.no_command");
    }

}

==> extra-tool-installers-0.2-sources.jar: com/synopsys/arc/jenkinsci/plugins/extratoolinstallers/installers/Messages.java <==
// CHECKSTYLE:OFF

package com.synopsys.arc.jenkinsci.plugins.extratoolinstallers.installers;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Must provide a tool home directory.
     * 
     */
    public static String SharedDirectoryInstaller_no_toolHome() {
        return holder.format("SharedDirectoryInstaller.no_toolHome");
    }

    /**
     * Must provide a tool home directory.
     * 
     */
    public static Localizable _SharedDirectoryInstaller_no_toolHome() {
        return new Localizable(holder, "SharedDirectoryInstaller.no_toolHome");
    }

    /**
     * Use tool from specified directory
     * 
     */
    public static String SharedDirectoryInstaller_DescriptorImpl_displayName() {
        return holder.format("SharedDirectoryInstaller.DescriptorImpl.displayName");
    }

    /**
     * Use tool from specified directory
     * 
     */
    public static Localizable _SharedDirectoryInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "SharedDirectoryInstaller.DescriptorImpl.displayName");
    }

    /**
     * Must provide a tool home directory.
     * 
     */
    public static String BatchCommandInstaller_no_toolHome() {
        return holder.format("BatchCommandInstaller.no_toolHome");
    }

    /**
     * Must provide a tool home directory.
     * 
     */
    public static Localizable _BatchCommandInstaller_no_toolHome() {
        return new Localizable(holder, "BatchCommandInstaller.no_toolHome");
    }

    /**
     * Skip or fail installation
     * 
     */
    public static String StubInstaller_displayName() {
        return holder.format("StubInstaller.displayName");
    }

    /**
     * Skip or fail installation
     * 
     */
    public static Localizable _StubInstaller_displayName() {
        return new Localizable(holder, "StubInstaller.displayName");
    }

    /**
     * No message specified. Default message will be used.
     * 
     */
    public static String StubInstaller_noMessage() {
        return holder.format("StubInstaller.noMessage");
    }

    /**
     * No message specified. Default message will be used.
     * 
     */
    public static Localizable _StubInstaller_noMessage() {
        return new Localizable(holder, "StubInstaller.noMessage");
    }

    /**
     * Run Batch Command
     * 
     */
    public static String BatchCommandInstaller_DescriptorImpl_displayName() {
        return holder.format("BatchCommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Run Batch Command
     * 
     */
    public static Localizable _BatchCommandInstaller_DescriptorImpl_displayName() {
        return new Localizable(holder, "BatchCommandInstaller.DescriptorImpl.displayName");
    }

    /**
     * Installation will be skipped
     * 
     */
    public static String StubInstaller_defaultMessage() {
        return holder.format("StubInstaller.defaultMessage");
    }

    /**
     * Installation will be skipped
     * 
     */
    public static Localizable _StubInstaller_defaultMessage() {
        return new Localizable(holder, "StubInstaller.defaultMessage");
    }

    /**
     * Must provide a command to run.
     * 
     */
    public static String BatchCommandInstaller_no_command() {
        return holder.format("BatchCommandInstaller.no_command");
    }

    /**
     * Must provide a command to run.
     * 
     */
    public static Localizable _BatchCommandInstaller_no_command() {
        return new Localizable(holder, "BatchCommandInstaller.no_command");
    }

}
